@@ -4,6 +4,7 @@ from typing import Dict, List, Optional
 import uvicorn
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
+from fastapi.middleware.gzip import GZipMiddleware
 from monty.json import MSONable
 from starlette.responses import RedirectResponse
 
@@ -88,6 +89,8 @@ class API(MSONable):
 
             app.include_router(main_resource.router, prefix=f"/{prefix}")
 
+        app.add_middleware(GZipMiddleware, minimum_size=1000)
+
         @app.get("/heartbeat", include_in_schema=False)
         def heartbeat():
             """API Heartbeat for Load Balancing"""
