@@ -5,6 +5,25 @@ from pathlib import Path
 import pytest
 
 
+@pytest.fixture
+def tmp_dir():
+    """
+    Create a clean directory and cd into it.
+
+    The directory will be removed at the end of the test.
+    """
+    import os
+    import shutil
+    import tempfile
+
+    old_cwd = os.getcwd()
+    newpath = tempfile.mkdtemp()
+    os.chdir(newpath)
+    yield
+    os.chdir(old_cwd)
+    shutil.rmtree(newpath)
+
+
 @pytest.fixture
 def test_dir():
     module_dir = Path(__file__).resolve().parent
@@ -25,6 +44,7 @@ def lp_file(test_dir):
     lp_file = db_dir / "my_launchpad.yaml"
     return lp_file.resolve()
 
+
 @pytest.fixture
 def log_to_stdout():
     # Set Logging
